==> vite-plugin-proxy-0.5.0-pre1.tgz: package/test/frontends/frontends.test.js <==
import { describe, it, expect, afterEach, jest } from '@jest/globals'
import path from 'path'
import vitePluginProxy from '../../src/index'
import { closeAllServers, createTestServer, createViteServer, generateSelfsigned, getPort, http2Request, updateRequestManager } from '../util'

const PORT = getPort()
const SERVER_PORT = getPort()
const SERVER_PORT2 = getPort()
const __dirname = path.dirname(new URL(import.meta.url).pathname)

describe('enhanced frontend configuration', function () {
  afterEach(async function () {
    await closeAllServers()
    updateRequestManager()
  })

  it('select a preferred frontend by path', async function () {
    await createViteServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [vitePluginProxy({
        frontends: [{
          target: `http://localhost:${SERVER_PORT}`,
          path: '/core'
        }, {
          target: `http://localhost:${SERVER_PORT2}`,
          path: '/plugin'
        }]
      })]
    }, PORT)

    const server = createTestServer()
    const mockCallback = jest.fn((req, res) => res.send('alert("foo")'))
    server.get('*', mockCallback)
    await server.listen({ port: SERVER_PORT })

    const server2 = createTestServer()
    const mockCallback2 = jest.fn((req, res) => res.send('alert("bar")'))
    server2.get('*', mockCallback2)
    await server2.listen({ port: SERVER_PORT2 })

    expect(mockCallback).toBeCalledTimes(0)
    expect(mockCallback2).toBeCalledTimes(0)

    const { data } = await http2Request(`http://localhost:${PORT}/core/file.js`)
    expect(data).toEqual('alert("foo")')
    expect(mockCallback).toBeCalledTimes(1)
    expect(mockCallback2).toBeCalledTimes(0)

    const { data: data2 } = await http2Request(`http://localhost:${PORT}/plugin/file.js`)
    expect(data2).toEqual('alert("bar")')
    expect(mockCallback).toBeCalledTimes(1)
    expect(mockCallback2).toBeCalledTimes(1)
  })

  it('select a preferred frontend by regex', async function () {
    await createViteServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [vitePluginProxy({
        frontends: [{
          target: `http://localhost:${SERVER_PORT}`,
          path: '^/core'
        }, {
          target: `http://localhost:${SERVER_PORT2}`,
          path: '^/(?!core)'
        }]
      })]
    }, PORT)

    const server = createTestServer()
    const mockCallback = jest.fn((req, res) => res.send('alert("foo")'))
    server.get('*', mockCallback)
    await server.listen({ port: SERVER_PORT })

    const server2 = createTestServer()
    const mockCallback2 = jest.fn((req, res) => res.send('alert("bar")'))
    server2.get('*', mockCallback2)
    await server2.listen({ port: SERVER_PORT2 })

    expect(mockCallback).toBeCalledTimes(0)
    expect(mockCallback2).toBeCalledTimes(0)

    const { data } = await http2Request(`http://localhost:${PORT}/core/file.js`)
    expect(data).toEqual('alert("foo")')
    expect(mockCallback).toBeCalledTimes(1)
    expect(mockCallback2).toBeCalledTimes(0)

    const { data: data2 } = await http2Request(`http://localhost:${PORT}/plugin/file.js`)
    expect(data2).toEqual('alert("bar")')
    expect(mockCallback).toBeCalledTimes(1)
    expect(mockCallback2).toBeCalledTimes(1)
  })

  it('supports secure=false', async function () {
    await createViteServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [vitePluginProxy({
        frontends: [{
          target: `https://localhost:${SERVER_PORT}`,
          secure: false
        }]
      })]
    }, PORT)

    const server = createTestServer({
      http2: true,
      https: generateSelfsigned()
    })
    server.get('*', (req, res) => res.send('alert("foo")'))
    await server.listen({ port: SERVER_PORT })

    await http2Request(`http://localhost:${PORT}/plugin/file.js`)
  })
})

==> vite-plugin-proxy-0.6.2.tgz: package/test/frontends/frontends.test.js <==
import { describe, it, expect, afterEach, jest } from '@jest/globals'
import path from 'path'
import vitePluginProxy from '../../src/index'
import { closeAllServers, createTestServer, createViteServer, filterPingCalls, generateSelfsigned, getPort, http2Request, updateRequestManager } from '../util'

const PORT = getPort()
const SERVER_PORT = getPort()
const SERVER_PORT2 = getPort()
const __dirname = path.dirname(new URL(import.meta.url).pathname)

describe('enhanced frontend configuration', function () {
  afterEach(async function () {
    await closeAllServers()
    updateRequestManager()
  })

  it('select a preferred frontend by path', async function () {
    await createViteServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [vitePluginProxy({
        frontends: [{
          target: `http://localhost:${SERVER_PORT}`,
          path: '/core'
        }, {
          target: `http://localhost:${SERVER_PORT2}`,
          path: '/plugin'
        }]
      })]
    }, PORT)

    const server = createTestServer()
    const mockCallback = jest.fn((req, res) => res.send('alert("foo")'))
    server.get('*', mockCallback)
    await server.listen({ port: SERVER_PORT })

    const server2 = createTestServer()
    const mockCallback2 = jest.fn((req, res) => res.send('alert("bar")'))
    server2.get('*', mockCallback2)
    await server2.listen({ port: SERVER_PORT2 })

    expect(filterPingCalls(mockCallback)).toBeCalledTimes(0)
    expect(filterPingCalls(mockCallback2)).toBeCalledTimes(0)

    const { data } = await http2Request(`http://localhost:${PORT}/core/file.js`)
    expect(data).toEqual('alert("foo")')
    expect(filterPingCalls(mockCallback)).toBeCalledTimes(1)
    expect(filterPingCalls(mockCallback2)).toBeCalledTimes(0)

    const { data: data2 } = await http2Request(`http://localhost:${PORT}/plugin/file.js`)
    expect(data2).toEqual('alert("bar")')
    expect(filterPingCalls(mockCallback)).toBeCalledTimes(1)
    expect(filterPingCalls(mockCallback2)).toBeCalledTimes(1)
  })

  it('select a preferred frontend by regex', async function () {
    await createViteServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [vitePluginProxy({
        frontends: [{
          target: `http://localhost:${SERVER_PORT}`,
          path: '^/core'
        }, {
          target: `http://localhost:${SERVER_PORT2}`,
          path: '^/(?!core)'
        }]
      })]
    }, PORT)

    const server = createTestServer()
    const mockCallback = jest.fn((req, res) => res.send('alert("foo")'))
    server.get('*', mockCallback)
    await server.listen({ port: SERVER_PORT })

    const server2 = createTestServer()
    const mockCallback2 = jest.fn((req, res) => res.send('alert("bar")'))
    server2.get('*', mockCallback2)
    await server2.listen({ port: SERVER_PORT2 })

    expect(filterPingCalls(mockCallback)).toBeCalledTimes(0)
    expect(filterPingCalls(mockCallback2)).toBeCalledTimes(0)

    const { data } = await http2Request(`http://localhost:${PORT}/core/file.js`)
    expect(data).toEqual('alert("foo")')
    expect(filterPingCalls(mockCallback)).toBeCalledTimes(1)
    expect(filterPingCalls(mockCallback2)).toBeCalledTimes(0)

    const { data: data2 } = await http2Request(`http://localhost:${PORT}/plugin/file.js`)
    expect(data2).toEqual('alert("bar")')
    expect(filterPingCalls(mockCallback)).toBeCalledTimes(1)
    expect(filterPingCalls(mockCallback2)).toBeCalledTimes(1)
  })

  it('supports secure=false', async function () {
    await createViteServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [vitePluginProxy({
        frontends: [{
          target: `https://localhost:${SERVER_PORT}`,
          secure: false
        }]
      })]
    }, PORT)

    const server = createTestServer({
      http2: true,
      https: generateSelfsigned()
    })
    server.get('*', (req, res) => res.send('alert("foo")'))
    await server.listen({ port: SERVER_PORT })

    await http2Request(`http://localhost:${PORT}/plugin/file.js`)
  })
})
